@@ -23,8 +23,8 @@ using namespace UCOMMON_NAMESPACE;
 static shell::flagopt helpflag('h',"--help",    _TEXT("display this list"));
 static shell::flagopt althelp('?', NULL, NULL);
 static shell::stringopt hash('d', "--digest", _TEXT("digest method (md5)"), "method", "md5");
-static shell::flagopt follow('f', "--follow", _TEXT("follow symlinks"));
 static shell::flagopt recursive('R', "--recursive", _TEXT("recursive directory scan"));
+static shell::flagopt altrecursive('r', NULL, NULL);
 static shell::flagopt hidden('s', "--hidden", _TEXT("show hidden files"));
 
 static int exit_code = 0;
@@ -101,9 +101,6 @@ static void digest(const char *path = NULL)
     if(path) {
         int err = fsys::stat(path, &ino);
 
-        if(!err && fsys::islink(&ino) && !is(follow))
-            err = EBADF;
-
         if(err) {
             result(path, err);
             return;
@@ -136,7 +133,7 @@ static void digest(const char *path = NULL)
     md.reset();
 }
 
-static void dirpath(String path, bool top = true)
+static void scan(String path, bool top = true)
 {
     char filename[128];
     String filepath;
@@ -151,8 +148,8 @@ static void dirpath(String path, bool top = true)
 
         filepath = str(path) + str("/") + str(filename);
         if(fsys::isdir(filepath)) {
-            if(is(recursive))
-                dirpath(filepath, false);
+            if(is(recursive) || is(altrecursive))
+                scan(filepath, false);
             else
                 result(filepath, EISDIR);
         }
@@ -172,7 +169,7 @@ PROGRAM_MAIN(argc, argv)
 
     if(is(helpflag) || is(althelp)) {
         printf("%s\n", _TEXT("Usage: mdsum [options] path..."));
-        printf("%s\n\n", _TEXT("Echo command line arguments"));
+        printf("%s\n\n", _TEXT("Compute digests for files"));
         printf("%s\n", _TEXT("Options:"));
         shell::help();
         printf("\n%s\n", _TEXT("Report bugs to dyfet@gnu.org"));
@@ -194,7 +191,7 @@ PROGRAM_MAIN(argc, argv)
         digest();
     else while(count < args()) {
         if(fsys::isdir(args[count]))
-            dirpath(str(args[count++]));
+            scan(str(args[count++]));
         else
             digest(args[count++]);
     }
